@@ -52,12 +52,14 @@ after_columns_tokens = {
     "LOCATION": "LOCATION",
     "ROW": "ROW",
     "FORMAT": "FORMAT",
-    "FIELDS": "FIELDS",
     "TERMINATED": "TERMINATED",
     "COLLECTION": "COLLECTION",
     "ITEMS": "ITEMS",
     "MAP": "MAP",
     "KEYS": "KEYS",
+    "SERDE": "SERDE",
+    "WITH": "WITH",
+    "SERDEPROPERTIES": "SERDEPROPERTIES",
     # oracle
     "STORAGE": "STORAGE",
     "TABLESPACE": "TABLESPACE",
